changeset 111671:a608fdf9cdc5

* textmodes/reftex-ref.el (reftex-goto-label): Use the current \ref's or \pageref's value as default instead of initial input.
author Tassilo Horn <tassilo@member.fsf.org>
date Mon, 22 Nov 2010 09:09:41 +0100
parents f736e5e4fef4
children 7c6e6f2b3351
files lisp/ChangeLog lisp/textmodes/reftex-ref.el
diffstat 2 files changed, 17 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Sun Nov 21 19:43:53 2010 -0500
+++ b/lisp/ChangeLog	Mon Nov 22 09:09:41 2010 +0100
@@ -1,3 +1,8 @@
+2010-11-22  Tassilo Horn  <tassilo@member.fsf.org>
+
+	* textmodes/reftex-ref.el (reftex-goto-label): Use the current
+	\ref's or \pageref's value as default instead of initial input.
+
 2010-11-21  Michael Albinus  <michael.albinus@gmx.de>
 
 	* files.el (backup-by-copying-when-mismatch): The default value is
--- a/lisp/textmodes/reftex-ref.el	Sun Nov 21 19:43:53 2010 -0500
+++ b/lisp/textmodes/reftex-ref.el	Mon Nov 22 09:09:41 2010 +0100
@@ -237,9 +237,9 @@
         (setq label default))
 
       ;; Insert the label into the label list
-      (let* ((here-I-am-info 
+      (let* ((here-I-am-info
               (save-excursion
-                (if (and (or naked no-insert) 
+                (if (and (or naked no-insert)
                          (integerp (cdr macro-cell)))
                     (goto-char (cdr macro-cell)))
                 (reftex-where-am-I)))
@@ -830,13 +830,16 @@
   (reftex-access-scan-info)
   (let* ((wcfg (current-window-configuration))
          (docstruct (symbol-value reftex-docstruct-symbol))
-         (label (completing-read "Label: " docstruct
-                                 (lambda (x) (stringp (car x))) t
-				 ;; If point is inside a \ref{} or
-				 ;; \pageref{}, use that as initial
-				 ;; input.
-				 (when (looking-back "\\\\\\(?:page\\)?ref{[-a-zA-Z0-9_*.:]*")
-				   (reftex-this-word "-a-zA-Z0-9_*.:"))))
+	 ;; If point is inside a \ref{} or \pageref{}, use that as
+	 ;; default value.
+	 (default (when (looking-back "\\\\\\(?:page\\)?ref{[-a-zA-Z0-9_*.:]*")
+		    (reftex-this-word "-a-zA-Z0-9_*.:")))
+         (label (completing-read (if default
+				     (format "Label (default %s): " default)
+				   "Label: ")
+				 docstruct
+                                 (lambda (x) (stringp (car x))) t nil nil
+				 default))
          (selection (assoc label docstruct))
          (where (progn
                   (reftex-show-label-location selection t nil 'stay)